# Adecty Design

## 1. About

Adecty Design is a module with which you can greatly simplify the development of the UI.

## 2. Versions

- 0.1.0 (2023-01-12):
    - application structure;
    - basic elements.

## 3. License

(c) 2022, Yegor Yakubovich

Licensed under the Apache License, Version 2.0 (the "License");

you may not use this file except in compliance with the License.

You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software

distributed under the License is distributed on an "AS IS" BASIS,

WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and

limitations under the License.
